==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/ServiceOciArtifactEntryArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.ServiceOciArtifactEntryArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * An Open Container Initiative (OCI) artifact.
 * @property digest The artifact digest.
 * @property imageName The artifact name.
 * @property loginServer The Azure Container Registry login server.
 */
public data class ServiceOciArtifactEntryArgs(
    public val digest: Output<String>? = null,
    public val imageName: Output<String>? = null,
    public val loginServer: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.ServiceOciArtifactEntryArgs> {
    override fun toJava(): com.pulumi.azurenative.healthcareapis.inputs.ServiceOciArtifactEntryArgs =
        com.pulumi.azurenative.healthcareapis.inputs.ServiceOciArtifactEntryArgs.builder()
            .digest(digest?.applyValue({ args0 -> args0 }))
            .imageName(imageName?.applyValue({ args0 -> args0 }))
            .loginServer(loginServer?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServiceOciArtifactEntryArgs].
 */
@PulumiTagMarker
public class ServiceOciArtifactEntryArgsBuilder internal constructor() {
    private var digest: Output<String>? = null

    private var imageName: Output<String>? = null

    private var loginServer: Output<String>? = null

    /**
     * @param value The artifact digest.
     */
    @JvmName("cgekrlfbpqirtapv")
    public suspend fun digest(`value`: Output<String>) {
        this.digest = value
    }

    /**
     * @param value The artifact name.
     */
    @JvmName("wjtxkwpwwvplokpt")
    public suspend fun imageName(`value`: Output<String>) {
        this.imageName = value
    }

    /**
     * @param value The Azure Container Registry login server.
     */
    @JvmName("vhqrkdxxdvmshbgy")
    public suspend fun loginServer(`value`: Output<String>) {
        this.loginServer = value
    }

    /**
     * @param value The artifact digest.
     */
    @JvmName("owatjbrbetyfxlde")
    public suspend fun digest(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.digest = mapped
    }

    /**
     * @param value The artifact name.
     */
    @JvmName("uakgbdevoavmnwil")
    public suspend fun imageName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.imageName = mapped
    }

    /**
     * @param value The Azure Container Registry login server.
     */
    @JvmName("yrnqinbfvcxfgoym")
    public suspend fun loginServer(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.loginServer = mapped
    }

    internal fun build(): ServiceOciArtifactEntryArgs = ServiceOciArtifactEntryArgs(
        digest = digest,
        imageName = imageName,
        loginServer = loginServer,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/healthcareapis/kotlin/inputs/ServiceOciArtifactEntryArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.healthcareapis.kotlin.inputs

import com.pulumi.azurenative.healthcareapis.inputs.ServiceOciArtifactEntryArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * An Open Container Initiative (OCI) artifact.
 * @property digest The artifact digest.
 * @property imageName The artifact name.
 * @property loginServer The Azure Container Registry login server.
 */
public data class ServiceOciArtifactEntryArgs(
    public val digest: Output<String>? = null,
    public val imageName: Output<String>? = null,
    public val loginServer: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.healthcareapis.inputs.ServiceOciArtifactEntryArgs> {
    override fun toJava(): com.pulumi.azurenative.healthcareapis.inputs.ServiceOciArtifactEntryArgs =
        com.pulumi.azurenative.healthcareapis.inputs.ServiceOciArtifactEntryArgs.builder()
            .digest(digest?.applyValue({ args0 -> args0 }))
            .imageName(imageName?.applyValue({ args0 -> args0 }))
            .loginServer(loginServer?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServiceOciArtifactEntryArgs].
 */
@PulumiTagMarker
public class ServiceOciArtifactEntryArgsBuilder internal constructor() {
    private var digest: Output<String>? = null

    private var imageName: Output<String>? = null

    private var loginServer: Output<String>? = null

    /**
     * @param value The artifact digest.
     */
    @JvmName("htpgccwowqosryyi")
    public suspend fun digest(`value`: Output<String>) {
        this.digest = value
    }

    /**
     * @param value The artifact name.
     */
    @JvmName("dtgajnfowqufkukr")
    public suspend fun imageName(`value`: Output<String>) {
        this.imageName = value
    }

    /**
     * @param value The Azure Container Registry login server.
     */
    @JvmName("wjxebpbrxsjshlbe")
    public suspend fun loginServer(`value`: Output<String>) {
        this.loginServer = value
    }

    /**
     * @param value The artifact digest.
     */
    @JvmName("ixamkumravwwjtgv")
    public suspend fun digest(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.digest = mapped
    }

    /**
     * @param value The artifact name.
     */
    @JvmName("rnxyxvntwdatauoo")
    public suspend fun imageName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.imageName = mapped
    }

    /**
     * @param value The Azure Container Registry login server.
     */
    @JvmName("onkjtuhikdhjkygy")
    public suspend fun loginServer(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.loginServer = mapped
    }

    internal fun build(): ServiceOciArtifactEntryArgs = ServiceOciArtifactEntryArgs(
        digest = digest,
        imageName = imageName,
        loginServer = loginServer,
    )
}
